@@ -13,6 +13,7 @@ from ._server import (register,
                       callable_as, 
                       Serializable,
                       serializable_type,
+                      portable_class,
                       _register_exception_type, 
                       AnvilWrappedError, 
                       SerializationError, 
@@ -33,6 +34,7 @@ from ._server import (register,
                       api_request as request, 
                       HttpResponse, 
                       Capability,
+                      unwrap_capability,
                       cookies,
                       CallContext)
 
