@@ -1,6 +1,6 @@
 import anvil.server
 from anvil import *
-from .exceptions import UserExists, AuthenticationFailed, EmailNotConfirmed, AccountIsNotEnabled, PasswordNotAcceptable, MFARequired, PasswordResetRequested
+from .exceptions import UserExists, AuthenticationFailed, EmailNotConfirmed, AccountIsNotEnabled, PasswordNotAcceptable, MFARequired, PasswordResetRequested, TooManyPasswordFailures
 from .config import get_client_config
 
 #!suggestAttr(anvil.users,login_with_form)!0:
@@ -14,6 +14,7 @@ anvil.server._register_exception_type("anvil.users.UserExists", UserExists)
 anvil.server._register_exception_type("anvil.users.AuthenticationFailed", AuthenticationFailed)
 anvil.server._register_exception_type("anvil.users.EmailNotConfirmed", EmailNotConfirmed)
 anvil.server._register_exception_type("anvil.users.AccountIsNotEnabled", AccountIsNotEnabled)
+anvil.server._register_exception_type("anvil.users.TooManyPasswordFailures", TooManyPasswordFailures)
 anvil.server._register_exception_type("anvil.users.PasswordNotAcceptable", PasswordNotAcceptable)
 anvil.server._register_exception_type("anvil.users.MFARequired", MFARequired)
 anvil.server._register_exception_type("anvil.users.PasswordResetRequested", PasswordResetRequested)
